==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitSounds.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_7923;

public final class InitSounds {
    public static void init() {

    }

    public static final class_3414 MAID_IDLE = registerSound("maid.mode.idle");
    public static final class_3414 MAID_ATTACK = registerSound("maid.mode.attack");
    public static final class_3414 MAID_RANGE_ATTACK = registerSound("maid.mode.range_attack");
    public static final class_3414 MAID_DANMAKU_ATTACK = registerSound("maid.mode.danmaku_attack");
    public static final class_3414 MAID_FARM = registerSound("maid.mode.farm");
    public static final class_3414 MAID_FEED = registerSound("maid.mode.feed");
    public static final class_3414 MAID_SHEARS = registerSound("maid.mode.shears");
    public static final class_3414 MAID_MILK = registerSound("maid.mode.milk");
    public static final class_3414 MAID_REMOVE_SNOW = registerSound("maid.mode.snow");
    public static final class_3414 MAID_TORCH = registerSound("maid.mode.torch");
    public static final class_3414 MAID_FEED_ANIMAL = registerSound("maid.mode.feed_animal");
    public static final class_3414 MAID_EXTINGUISHING = registerSound("maid.mode.extinguishing");
    public static final class_3414 MAID_BREAK = registerSound("maid.mode.break");
    public static final class_3414 MAID_FURNACE = registerSound("maid.mode.furnace");
    public static final class_3414 MAID_BREWING = registerSound("maid.mode.brewing");
    public static final class_3414 MAID_FIND_TARGET = registerSound("maid.ai.find_target");
    public static final class_3414 MAID_HURT = registerSound("maid.ai.hurt");
    public static final class_3414 MAID_HURT_FIRE = registerSound("maid.ai.hurt_fire");
    public static final class_3414 MAID_PLAYER = registerSound("maid.ai.hurt_player");
    public static final class_3414 MAID_TAMED = registerSound("maid.ai.tamed");
    public static final class_3414 MAID_ITEM_GET = registerSound("maid.ai.item_get");
    public static final class_3414 MAID_DEATH = registerSound("maid.ai.death");
    public static final class_3414 GAME_WIN = registerSound("maid.ai.game_win");
    public static final class_3414 GAME_LOST = registerSound("maid.ai.game_lost");
    public static final class_3414 MAID_HOT = registerSound("maid.environment.hot");
    public static final class_3414 MAID_COLD = registerSound("maid.environment.cold");
    public static final class_3414 MAID_RAIN = registerSound("maid.environment.rain");
    public static final class_3414 MAID_SNOW = registerSound("maid.environment.snow");
    public static final class_3414 MAID_MORNING = registerSound("maid.environment.morning");
    public static final class_3414 MAID_NIGHT = registerSound("maid.environment.night");
    public static final class_3414 MAID_CREDIT = registerSound("maid.credit");
    public static final class_3414 MAID_AI_CHAT = registerSound("maid.ai_chat");
    public static final class_3414 CAMERA_USE = registerSound("item.camera_use");
    public static final class_3414 ALTAR_CRAFT = registerSound("block.altar_craft");
    public static final class_3414 GOMOKU = registerSound("block.gomoku");
    public static final class_3414 GOMOKU_RESET = registerSound("block.gomoku_reset");
    public static final class_3414 BOX_OPEN = registerSound("entity.box");
    public static final class_3414 COMPASS_POINT = registerSound("item.compass");
    public static final class_3414 FAIRY_AMBIENT = registerSound("entity.fairy.ambient");
    public static final class_3414 FAIRY_DEATH = registerSound("entity.fairy.death");
    public static final class_3414 FAIRY_HURT = registerSound("entity.fairy.hurt");

    private static class_3414 registerSound(String name) {
        class_2960 id = class_2960.method_60655(TouhouLittleMaid.MOD_ID, name);
        return class_2378.method_10230(class_7923.field_41172, id, class_3414.method_47909(id, 16.0F));
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.4.3-neo1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitSounds.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_7923;

public final class InitSounds {
    public static void init() {

    }

    public static final class_3414 MAID_IDLE = registerSound("maid.mode.idle");
    public static final class_3414 MAID_ATTACK = registerSound("maid.mode.attack");
    public static final class_3414 MAID_RANGE_ATTACK = registerSound("maid.mode.range_attack");
    public static final class_3414 MAID_DANMAKU_ATTACK = registerSound("maid.mode.danmaku_attack");
    public static final class_3414 MAID_FARM = registerSound("maid.mode.farm");
    public static final class_3414 MAID_FEED = registerSound("maid.mode.feed");
    public static final class_3414 MAID_SHEARS = registerSound("maid.mode.shears");
    public static final class_3414 MAID_MILK = registerSound("maid.mode.milk");
    public static final class_3414 MAID_REMOVE_SNOW = registerSound("maid.mode.snow");
    public static final class_3414 MAID_TORCH = registerSound("maid.mode.torch");
    public static final class_3414 MAID_FEED_ANIMAL = registerSound("maid.mode.feed_animal");
    public static final class_3414 MAID_EXTINGUISHING = registerSound("maid.mode.extinguishing");
    public static final class_3414 MAID_BREAK = registerSound("maid.mode.break");
    public static final class_3414 MAID_FURNACE = registerSound("maid.mode.furnace");
    public static final class_3414 MAID_BREWING = registerSound("maid.mode.brewing");
    public static final class_3414 MAID_FIND_TARGET = registerSound("maid.ai.find_target");
    public static final class_3414 MAID_HURT = registerSound("maid.ai.hurt");
    public static final class_3414 MAID_HURT_FIRE = registerSound("maid.ai.hurt_fire");
    public static final class_3414 MAID_PLAYER = registerSound("maid.ai.hurt_player");
    public static final class_3414 MAID_TAMED = registerSound("maid.ai.tamed");
    public static final class_3414 MAID_ITEM_GET = registerSound("maid.ai.item_get");
    public static final class_3414 MAID_DEATH = registerSound("maid.ai.death");
    public static final class_3414 GAME_WIN = registerSound("maid.ai.game_win");
    public static final class_3414 GAME_LOST = registerSound("maid.ai.game_lost");
    public static final class_3414 MAID_HOT = registerSound("maid.environment.hot");
    public static final class_3414 MAID_COLD = registerSound("maid.environment.cold");
    public static final class_3414 MAID_RAIN = registerSound("maid.environment.rain");
    public static final class_3414 MAID_SNOW = registerSound("maid.environment.snow");
    public static final class_3414 MAID_MORNING = registerSound("maid.environment.morning");
    public static final class_3414 MAID_NIGHT = registerSound("maid.environment.night");
    public static final class_3414 MAID_CREDIT = registerSound("maid.credit");
    public static final class_3414 MAID_AI_CHAT = registerSound("maid.ai_chat");
    public static final class_3414 CAMERA_USE = registerSound("item.camera_use");
    public static final class_3414 ALTAR_CRAFT = registerSound("block.altar_craft");
    public static final class_3414 GOMOKU = registerSound("block.gomoku");
    public static final class_3414 GOMOKU_RESET = registerSound("block.gomoku_reset");
    public static final class_3414 BOX_OPEN = registerSound("entity.box");
    public static final class_3414 COMPASS_POINT = registerSound("item.compass");
    public static final class_3414 FAIRY_AMBIENT = registerSound("entity.fairy.ambient");
    public static final class_3414 FAIRY_DEATH = registerSound("entity.fairy.death");
    public static final class_3414 FAIRY_HURT = registerSound("entity.fairy.hurt");
    public static final class_3414 RECORDING_START = registerSound("ui.recording_start");
    public static final class_3414 RECORDING_END = registerSound("ui.recording_end");

    private static class_3414 registerSound(String name) {
        class_2960 id = class_2960.method_60655(TouhouLittleMaid.MOD_ID, name);
        return class_2378.method_10230(class_7923.field_41172, id, class_3414.method_47909(id, 16.0F));
    }
}
